// Author: Alexander S. Gerasimov

#include <iostream>


// A class meant to be the parent of classes which instances can be tested
// for equality.
class TestableForEquality {
public:
    // Returns true iff this instance is equal to *pte.
    // The implementation of this method in this class
    // returns true iff pte points to this instance.
    virtual bool equals(TestableForEquality* pte);
    virtual ~TestableForEquality() {}
};


bool TestableForEquality::equals(TestableForEquality* pte) {
    return this == pte;
}


// Performs linear search for *x (the object addressed by the pointer x)
// in the array vec. The lenght of the array is the argument size.
// Returns a negative integer if *x is not found in vec; otherwise returns
// the leftmost index in vec that addresses an instance equal to *x.
int linSearch(TestableForEquality* vec[], int size, TestableForEquality* x) {
    for (int k = 0; k < size; k++) {
        if (vec[k]->equals(x)) return k;
    }
    return -1;
}


// A class that wraps an integer.
class Int : public TestableForEquality {
private:
    int data;
public:
    Int();
    Int(int i);
    virtual ~Int();
    virtual bool equals(TestableForEquality* pte);
    void set(int i);
    int get();
};


Int::Int() {
    data = 0;
    std::cout<<"Int()\n";
}

Int::Int(int i) {
    data = i;
    std::cout<<"Int("<<i<<")\n";
}

Int::~Int() { // does nothing important, just for test
    std::cout<<"~Int(): data="<<data<<'\n';
}

bool Int::equals(TestableForEquality* pte) {
    Int* p = dynamic_cast<Int*>(pte);
    if (p != 0) { // the object addressed by pte is an instance of the class Int
        return (data == p->data);
    } else {
        return false;
    }
}

void Int::set(int i) { data = i; }

int Int::get() { return data; }



int main() {
    const int DEFAULT_SIZE = 3;
    int size;
    std::cin>>size;
    if (size < 0) size = DEFAULT_SIZE;

    TestableForEquality** vec = new TestableForEquality*[size];
    for (int k = 0; k < size; k++) {
        int m;
        std::cin>>m;
        vec[k] = new Int(m);
    }

    int m;
    std::cin>>m;
    TestableForEquality* x = new Int(m);

    std::cout<<"Index found: "<<linSearch(vec, size, x)<<'\n';

    for (int k = 0; k < size; k++) {
        delete vec[k];
    }
    delete[] vec;
    delete x;
    return 0;
}
